plot.probeset-methods: description of function plot.probeset

Description Usage Arguments Examples

Description

This function plots the expression data grouped by the GroupName using ggplot2.

Works only for one probeset.

Usage

1
2
plot.probeset(x, probeset, boxplot = F, pdf = F,
  geneNameCol = "mgi_symbol", sampleGroup = "GroupName")

Arguments

x

the ExpressionSet object

probeset

the probeset name (rownames(x@data))

boxplot

(F or T) create a a dots- or box-plot

pdf

save the file as pdf (default svg)

geneNameCol

the column name for the gene symbol to use in the plots

sampleGroup

the sample table column containing the grouping information

groupcol

the grouping column in the samples data

colCol

the coloring column in the sample data

probeNames

the column in the annotation datacontaining the gene symbol

x

the ExpressionSet object

Examples

1
2
3
4
p <- plot.probeset( red, rownames(red@data)[20], geneNameCol= 'GeneID', boxplot=T)
#produces the file '../../tmp/reducedSet_boxplot_Mybl1_expression.svg'
p <- plot.probeset( red, rownames(red@data)[20], geneNameCol= 'GeneID', boxplot=F)
#produces the file '../../tmp/reducedSet_points_Mybl1_expression.svg'

stela2502/ExpressionSet documentation built on May 30, 2019, 2:35 p.m.